clone

package module
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2022 License: BSL-1.0 Imports: 1 Imported by: 0

README

clone

GoDoc

About

This package provides the function "clone" for slices of basic types. It is published on https://github.com/vbsw/slices/clone and https://gitlab.com/vbsw/slices/clone.

Copyright 2018, 2020, 2022, Vitali Baumtrok (vbsw@mailbox.org).

clone is distributed under the Boost Software License, version 1.0. (See accompanying file LICENSE or copy at http://www.boost.org/LICENSE_1_0.txt)

clone is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the Boost Software License for more details.

References

Documentation

Overview

Package clone provides the "clone" function for slices of basic types.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Bool

func Bool(list []bool) []bool

Bool makes a copy of the given list. The copy is returned.

func BoolD2

func BoolD2(list [][]bool) [][]bool

BoolD2 makes a shallow copy of the given list. The copy is returned.

func BoolD2DeepCopy

func BoolD2DeepCopy(list [][]bool) [][]bool

BoolD2DeepCopy makes a deep copy of the given list. The copy is returned.

func BoolD3

func BoolD3(list [][][]bool) [][][]bool

BoolD3 makes a shallow copy of the given list. The copy is returned.

func BoolD3DeepCopy

func BoolD3DeepCopy(list [][][]bool) [][][]bool

BoolD3DeepCopy makes a deep copy of the given list. The copy is returned.

func BoolD4

func BoolD4(list [][][][]bool) [][][][]bool

BoolD4 makes a shallow copy of the given list. The copy is returned.

func BoolD4DeepCopy

func BoolD4DeepCopy(list [][][][]bool) [][][][]bool

BoolD4DeepCopy makes a deep copy of the given list. The copy is returned.

func BoolD5

func BoolD5(list [][][][][]bool) [][][][][]bool

BoolD5 makes a shallow copy of the given list. The copy is returned.

func BoolD5DeepCopy

func BoolD5DeepCopy(list [][][][][]bool) [][][][][]bool

BoolD5DeepCopy makes a deep copy of the given list. The copy is returned.

func Byte

func Byte(list []byte) []byte

Byte makes a copy of the given list. The copy is returned.

func ByteD2

func ByteD2(list [][]byte) [][]byte

ByteD2 makes a shallow copy of the given list. The copy is returned.

func ByteD2DeepCopy

func ByteD2DeepCopy(list [][]byte) [][]byte

ByteD2DeepCopy makes a deep copy of the given list. The copy is returned.

func ByteD3

func ByteD3(list [][][]byte) [][][]byte

ByteD3 makes a shallow copy of the given list. The copy is returned.

func ByteD3DeepCopy

func ByteD3DeepCopy(list [][][]byte) [][][]byte

ByteD3DeepCopy makes a deep copy of the given list. The copy is returned.

func ByteD4

func ByteD4(list [][][][]byte) [][][][]byte

ByteD4 makes a shallow copy of the given list. The copy is returned.

func ByteD4DeepCopy

func ByteD4DeepCopy(list [][][][]byte) [][][][]byte

ByteD4DeepCopy makes a deep copy of the given list. The copy is returned.

func ByteD5

func ByteD5(list [][][][][]byte) [][][][][]byte

ByteD5 makes a shallow copy of the given list. The copy is returned.

func ByteD5DeepCopy

func ByteD5DeepCopy(list [][][][][]byte) [][][][][]byte

ByteD5DeepCopy makes a deep copy of the given list. The copy is returned.

func Complex128

func Complex128(list []complex128) []complex128

Complex128 makes a copy of the given list. The copy is returned.

func Complex128D2

func Complex128D2(list [][]complex128) [][]complex128

Complex128D2 makes a shallow copy of the given list. The copy is returned.

func Complex128D2DeepCopy

func Complex128D2DeepCopy(list [][]complex128) [][]complex128

Complex128D2DeepCopy makes a deep copy of the given list. The copy is returned.

func Complex128D3

func Complex128D3(list [][][]complex128) [][][]complex128

Complex128D3 makes a shallow copy of the given list. The copy is returned.

func Complex128D3DeepCopy

func Complex128D3DeepCopy(list [][][]complex128) [][][]complex128

Complex128D3DeepCopy makes a deep copy of the given list. The copy is returned.

func Complex128D4

func Complex128D4(list [][][][]complex128) [][][][]complex128

Complex128D4 makes a shallow copy of the given list. The copy is returned.

func Complex128D4DeepCopy

func Complex128D4DeepCopy(list [][][][]complex128) [][][][]complex128

Complex128D4DeepCopy makes a deep copy of the given list. The copy is returned.

func Complex128D5

func Complex128D5(list [][][][][]complex128) [][][][][]complex128

Complex128D5 makes a shallow copy of the given list. The copy is returned.

func Complex128D5DeepCopy

func Complex128D5DeepCopy(list [][][][][]complex128) [][][][][]complex128

Complex128D5DeepCopy makes a deep copy of the given list. The copy is returned.

func Complex64

func Complex64(list []complex64) []complex64

Complex64 makes a copy of the given list. The copy is returned.

func Complex64D2

func Complex64D2(list [][]complex64) [][]complex64

Complex64D2 makes a shallow copy of the given list. The copy is returned.

func Complex64D2DeepCopy

func Complex64D2DeepCopy(list [][]complex64) [][]complex64

Complex64D2DeepCopy makes a deep copy of the given list. The copy is returned.

func Complex64D3

func Complex64D3(list [][][]complex64) [][][]complex64

Complex64D3 makes a shallow copy of the given list. The copy is returned.

func Complex64D3DeepCopy

func Complex64D3DeepCopy(list [][][]complex64) [][][]complex64

Complex64D3DeepCopy makes a deep copy of the given list. The copy is returned.

func Complex64D4

func Complex64D4(list [][][][]complex64) [][][][]complex64

Complex64D4 makes a shallow copy of the given list. The copy is returned.

func Complex64D4DeepCopy

func Complex64D4DeepCopy(list [][][][]complex64) [][][][]complex64

Complex64D4DeepCopy makes a deep copy of the given list. The copy is returned.

func Complex64D5

func Complex64D5(list [][][][][]complex64) [][][][][]complex64

Complex64D5 makes a shallow copy of the given list. The copy is returned.

func Complex64D5DeepCopy

func Complex64D5DeepCopy(list [][][][][]complex64) [][][][][]complex64

Complex64D5DeepCopy makes a deep copy of the given list. The copy is returned.

func Error

func Error(list []error) []error

Error makes a copy of the given list. The copy is returned.

func ErrorD2

func ErrorD2(list [][]error) [][]error

ErrorD2 makes a shallow copy of the given list. The copy is returned.

func ErrorD2DeepCopy

func ErrorD2DeepCopy(list [][]error) [][]error

ErrorD2DeepCopy makes a deep copy of the given list. The copy is returned.

func ErrorD3

func ErrorD3(list [][][]error) [][][]error

ErrorD3 makes a shallow copy of the given list. The copy is returned.

func ErrorD3DeepCopy

func ErrorD3DeepCopy(list [][][]error) [][][]error

ErrorD3DeepCopy makes a deep copy of the given list. The copy is returned.

func ErrorD4

func ErrorD4(list [][][][]error) [][][][]error

ErrorD4 makes a shallow copy of the given list. The copy is returned.

func ErrorD4DeepCopy

func ErrorD4DeepCopy(list [][][][]error) [][][][]error

ErrorD4DeepCopy makes a deep copy of the given list. The copy is returned.

func ErrorD5

func ErrorD5(list [][][][][]error) [][][][][]error

ErrorD5 makes a shallow copy of the given list. The copy is returned.

func ErrorD5DeepCopy

func ErrorD5DeepCopy(list [][][][][]error) [][][][][]error

ErrorD5DeepCopy makes a deep copy of the given list. The copy is returned.

func Float32

func Float32(list []float32) []float32

Float32 makes a copy of the given list. The copy is returned.

func Float32D2

func Float32D2(list [][]float32) [][]float32

Float32D2 makes a shallow copy of the given list. The copy is returned.

func Float32D2DeepCopy

func Float32D2DeepCopy(list [][]float32) [][]float32

Float32D2DeepCopy makes a deep copy of the given list. The copy is returned.

func Float32D3

func Float32D3(list [][][]float32) [][][]float32

Float32D3 makes a shallow copy of the given list. The copy is returned.

func Float32D3DeepCopy

func Float32D3DeepCopy(list [][][]float32) [][][]float32

Float32D3DeepCopy makes a deep copy of the given list. The copy is returned.

func Float32D4

func Float32D4(list [][][][]float32) [][][][]float32

Float32D4 makes a shallow copy of the given list. The copy is returned.

func Float32D4DeepCopy

func Float32D4DeepCopy(list [][][][]float32) [][][][]float32

Float32D4DeepCopy makes a deep copy of the given list. The copy is returned.

func Float32D5

func Float32D5(list [][][][][]float32) [][][][][]float32

Float32D5 makes a shallow copy of the given list. The copy is returned.

func Float32D5DeepCopy

func Float32D5DeepCopy(list [][][][][]float32) [][][][][]float32

Float32D5DeepCopy makes a deep copy of the given list. The copy is returned.

func Float64

func Float64(list []float64) []float64

Float64 makes a copy of the given list. The copy is returned.

func Float64D2

func Float64D2(list [][]float64) [][]float64

Float64D2 makes a shallow copy of the given list. The copy is returned.

func Float64D2DeepCopy

func Float64D2DeepCopy(list [][]float64) [][]float64

Float64D2DeepCopy makes a deep copy of the given list. The copy is returned.

func Float64D3

func Float64D3(list [][][]float64) [][][]float64

Float64D3 makes a shallow copy of the given list. The copy is returned.

func Float64D3DeepCopy

func Float64D3DeepCopy(list [][][]float64) [][][]float64

Float64D3DeepCopy makes a deep copy of the given list. The copy is returned.

func Float64D4

func Float64D4(list [][][][]float64) [][][][]float64

Float64D4 makes a shallow copy of the given list. The copy is returned.

func Float64D4DeepCopy

func Float64D4DeepCopy(list [][][][]float64) [][][][]float64

Float64D4DeepCopy makes a deep copy of the given list. The copy is returned.

func Float64D5

func Float64D5(list [][][][][]float64) [][][][][]float64

Float64D5 makes a shallow copy of the given list. The copy is returned.

func Float64D5DeepCopy

func Float64D5DeepCopy(list [][][][][]float64) [][][][][]float64

Float64D5DeepCopy makes a deep copy of the given list. The copy is returned.

func Int

func Int(list []int) []int

Int makes a copy of the given list. The copy is returned.

func Int16

func Int16(list []int16) []int16

Int16 makes a copy of the given list. The copy is returned.

func Int16D2

func Int16D2(list [][]int16) [][]int16

Int16D2 makes a shallow copy of the given list. The copy is returned.

func Int16D2DeepCopy

func Int16D2DeepCopy(list [][]int16) [][]int16

Int16D2DeepCopy makes a deep copy of the given list. The copy is returned.

func Int16D3

func Int16D3(list [][][]int16) [][][]int16

Int16D3 makes a shallow copy of the given list. The copy is returned.

func Int16D3DeepCopy

func Int16D3DeepCopy(list [][][]int16) [][][]int16

Int16D3DeepCopy makes a deep copy of the given list. The copy is returned.

func Int16D4

func Int16D4(list [][][][]int16) [][][][]int16

Int16D4 makes a shallow copy of the given list. The copy is returned.

func Int16D4DeepCopy

func Int16D4DeepCopy(list [][][][]int16) [][][][]int16

Int16D4DeepCopy makes a deep copy of the given list. The copy is returned.

func Int16D5

func Int16D5(list [][][][][]int16) [][][][][]int16

Int16D5 makes a shallow copy of the given list. The copy is returned.

func Int16D5DeepCopy

func Int16D5DeepCopy(list [][][][][]int16) [][][][][]int16

Int16D5DeepCopy makes a deep copy of the given list. The copy is returned.

func Int32

func Int32(list []int32) []int32

Int32 makes a copy of the given list. The copy is returned.

func Int32D2

func Int32D2(list [][]int32) [][]int32

Int32D2 makes a shallow copy of the given list. The copy is returned.

func Int32D2DeepCopy

func Int32D2DeepCopy(list [][]int32) [][]int32

Int32D2DeepCopy makes a deep copy of the given list. The copy is returned.

func Int32D3

func Int32D3(list [][][]int32) [][][]int32

Int32D3 makes a shallow copy of the given list. The copy is returned.

func Int32D3DeepCopy

func Int32D3DeepCopy(list [][][]int32) [][][]int32

Int32D3DeepCopy makes a deep copy of the given list. The copy is returned.

func Int32D4

func Int32D4(list [][][][]int32) [][][][]int32

Int32D4 makes a shallow copy of the given list. The copy is returned.

func Int32D4DeepCopy

func Int32D4DeepCopy(list [][][][]int32) [][][][]int32

Int32D4DeepCopy makes a deep copy of the given list. The copy is returned.

func Int32D5

func Int32D5(list [][][][][]int32) [][][][][]int32

Int32D5 makes a shallow copy of the given list. The copy is returned.

func Int32D5DeepCopy

func Int32D5DeepCopy(list [][][][][]int32) [][][][][]int32

Int32D5DeepCopy makes a deep copy of the given list. The copy is returned.

func Int64

func Int64(list []int64) []int64

Int64 makes a copy of the given list. The copy is returned.

func Int64D2

func Int64D2(list [][]int64) [][]int64

Int64D2 makes a shallow copy of the given list. The copy is returned.

func Int64D2DeepCopy

func Int64D2DeepCopy(list [][]int64) [][]int64

Int64D2DeepCopy makes a deep copy of the given list. The copy is returned.

func Int64D3

func Int64D3(list [][][]int64) [][][]int64

Int64D3 makes a shallow copy of the given list. The copy is returned.

func Int64D3DeepCopy

func Int64D3DeepCopy(list [][][]int64) [][][]int64

Int64D3DeepCopy makes a deep copy of the given list. The copy is returned.

func Int64D4

func Int64D4(list [][][][]int64) [][][][]int64

Int64D4 makes a shallow copy of the given list. The copy is returned.

func Int64D4DeepCopy

func Int64D4DeepCopy(list [][][][]int64) [][][][]int64

Int64D4DeepCopy makes a deep copy of the given list. The copy is returned.

func Int64D5

func Int64D5(list [][][][][]int64) [][][][][]int64

Int64D5 makes a shallow copy of the given list. The copy is returned.

func Int64D5DeepCopy

func Int64D5DeepCopy(list [][][][][]int64) [][][][][]int64

Int64D5DeepCopy makes a deep copy of the given list. The copy is returned.

func Int8

func Int8(list []int8) []int8

Int8 makes a copy of the given list. The copy is returned.

func Int8D2

func Int8D2(list [][]int8) [][]int8

Int8D2 makes a shallow copy of the given list. The copy is returned.

func Int8D2DeepCopy

func Int8D2DeepCopy(list [][]int8) [][]int8

Int8D2DeepCopy makes a deep copy of the given list. The copy is returned.

func Int8D3

func Int8D3(list [][][]int8) [][][]int8

Int8D3 makes a shallow copy of the given list. The copy is returned.

func Int8D3DeepCopy

func Int8D3DeepCopy(list [][][]int8) [][][]int8

Int8D3DeepCopy makes a deep copy of the given list. The copy is returned.

func Int8D4

func Int8D4(list [][][][]int8) [][][][]int8

Int8D4 makes a shallow copy of the given list. The copy is returned.

func Int8D4DeepCopy

func Int8D4DeepCopy(list [][][][]int8) [][][][]int8

Int8D4DeepCopy makes a deep copy of the given list. The copy is returned.

func Int8D5

func Int8D5(list [][][][][]int8) [][][][][]int8

Int8D5 makes a shallow copy of the given list. The copy is returned.

func Int8D5DeepCopy

func Int8D5DeepCopy(list [][][][][]int8) [][][][][]int8

Int8D5DeepCopy makes a deep copy of the given list. The copy is returned.

func IntD2

func IntD2(list [][]int) [][]int

IntD2 makes a shallow copy of the given list. The copy is returned.

func IntD2DeepCopy

func IntD2DeepCopy(list [][]int) [][]int

IntD2DeepCopy makes a deep copy of the given list. The copy is returned.

func IntD3

func IntD3(list [][][]int) [][][]int

IntD3 makes a shallow copy of the given list. The copy is returned.

func IntD3DeepCopy

func IntD3DeepCopy(list [][][]int) [][][]int

IntD3DeepCopy makes a deep copy of the given list. The copy is returned.

func IntD4

func IntD4(list [][][][]int) [][][][]int

IntD4 makes a shallow copy of the given list. The copy is returned.

func IntD4DeepCopy

func IntD4DeepCopy(list [][][][]int) [][][][]int

IntD4DeepCopy makes a deep copy of the given list. The copy is returned.

func IntD5

func IntD5(list [][][][][]int) [][][][][]int

IntD5 makes a shallow copy of the given list. The copy is returned.

func IntD5DeepCopy

func IntD5DeepCopy(list [][][][][]int) [][][][][]int

IntD5DeepCopy makes a deep copy of the given list. The copy is returned.

func Interface

func Interface(list []interface{}) []interface{}

Interface makes a copy of the given list. The copy is returned. The object referenced by interface is not cloned.

func InterfaceD2

func InterfaceD2(list [][]interface{}) [][]interface{}

InterfaceD2 makes a shallow copy of the given list. The copy is returned.

func InterfaceD2DeepCopy

func InterfaceD2DeepCopy(list [][]interface{}) [][]interface{}

InterfaceD2DeepCopy makes a deep copy of the given list. The copy is returned. The object referenced by interface is not cloned.

func InterfaceD3

func InterfaceD3(list [][][]interface{}) [][][]interface{}

InterfaceD3 makes a shallow copy of the given list. The copy is returned.

func InterfaceD3DeepCopy

func InterfaceD3DeepCopy(list [][][]interface{}) [][][]interface{}

InterfaceD3DeepCopy makes a deep copy of the given list. The copy is returned. The object referenced by interface is not cloned.

func InterfaceD4

func InterfaceD4(list [][][][]interface{}) [][][][]interface{}

InterfaceD4 makes a shallow copy of the given list. The copy is returned.

func InterfaceD4DeepCopy

func InterfaceD4DeepCopy(list [][][][]interface{}) [][][][]interface{}

InterfaceD4DeepCopy makes a deep copy of the given list. The copy is returned. The object referenced by interface is not cloned.

func InterfaceD5

func InterfaceD5(list [][][][][]interface{}) [][][][][]interface{}

InterfaceD5 makes a shallow copy of the given list. The copy is returned.

func InterfaceD5DeepCopy

func InterfaceD5DeepCopy(list [][][][][]interface{}) [][][][][]interface{}

InterfaceD5DeepCopy makes a deep copy of the given list. The copy is returned. The object referenced by interface is not cloned.

func Pointer

func Pointer(list []unsafe.Pointer) []unsafe.Pointer

Pointer makes a copy of the given list. The copy is returned.

func PointerD2

func PointerD2(list [][]unsafe.Pointer) [][]unsafe.Pointer

PointerD2 makes a shallow copy of the given list. The copy is returned.

func PointerD2DeepCopy

func PointerD2DeepCopy(list [][]unsafe.Pointer) [][]unsafe.Pointer

PointerD2DeepCopy makes a deep copy of the given list. The copy is returned. The data the unsafe pointer is pointing to is not cloned.

func PointerD3

func PointerD3(list [][][]unsafe.Pointer) [][][]unsafe.Pointer

PointerD3 makes a shallow copy of the given list. The copy is returned.

func PointerD3DeepCopy

func PointerD3DeepCopy(list [][][]unsafe.Pointer) [][][]unsafe.Pointer

PointerD3DeepCopy makes a deep copy of the given list. The copy is returned. The data the unsafe pointer is pointing to is not cloned.

func PointerD4

func PointerD4(list [][][][]unsafe.Pointer) [][][][]unsafe.Pointer

PointerD4 makes a shallow copy of the given list. The copy is returned.

func PointerD4DeepCopy

func PointerD4DeepCopy(list [][][][]unsafe.Pointer) [][][][]unsafe.Pointer

PointerD4DeepCopy makes a deep copy of the given list. The copy is returned. The data the unsafe pointer is pointing to is not cloned.

func PointerD5

func PointerD5(list [][][][][]unsafe.Pointer) [][][][][]unsafe.Pointer

PointerD5 makes a shallow copy of the given list. The copy is returned.

func PointerD5DeepCopy

func PointerD5DeepCopy(list [][][][][]unsafe.Pointer) [][][][][]unsafe.Pointer

PointerD5DeepCopy makes a deep copy of the given list. The copy is returned. The data the unsafe pointer is pointing to is not cloned.

func Rune

func Rune(list []rune) []rune

Rune makes a copy of the given list. The copy is returned.

func RuneD2

func RuneD2(list [][]rune) [][]rune

RuneD2 makes a shallow copy of the given list. The copy is returned.

func RuneD2DeepCopy

func RuneD2DeepCopy(list [][]rune) [][]rune

RuneD2DeepCopy makes a deep copy of the given list. The copy is returned.

func RuneD3

func RuneD3(list [][][]rune) [][][]rune

RuneD3 makes a shallow copy of the given list. The copy is returned.

func RuneD3DeepCopy

func RuneD3DeepCopy(list [][][]rune) [][][]rune

RuneD3DeepCopy makes a deep copy of the given list. The copy is returned.

func RuneD4

func RuneD4(list [][][][]rune) [][][][]rune

RuneD4 makes a shallow copy of the given list. The copy is returned.

func RuneD4DeepCopy

func RuneD4DeepCopy(list [][][][]rune) [][][][]rune

RuneD4DeepCopy makes a deep copy of the given list. The copy is returned.

func RuneD5

func RuneD5(list [][][][][]rune) [][][][][]rune

RuneD5 makes a shallow copy of the given list. The copy is returned.

func RuneD5DeepCopy

func RuneD5DeepCopy(list [][][][][]rune) [][][][][]rune

RuneD5DeepCopy makes a deep copy of the given list. The copy is returned.

func String

func String(list []string) []string

String makes a copy of the given list. The copy is returned.

func StringD2

func StringD2(list [][]string) [][]string

StringD2 makes a shallow copy of the given list. The copy is returned.

func StringD2DeepCopy

func StringD2DeepCopy(list [][]string) [][]string

StringD2DeepCopy makes a deep copy of the given list. The copy is returned.

func StringD3

func StringD3(list [][][]string) [][][]string

StringD3 makes a shallow copy of the given list. The copy is returned.

func StringD3DeepCopy

func StringD3DeepCopy(list [][][]string) [][][]string

StringD3DeepCopy makes a deep copy of the given list. The copy is returned.

func StringD4

func StringD4(list [][][][]string) [][][][]string

StringD4 makes a shallow copy of the given list. The copy is returned.

func StringD4DeepCopy

func StringD4DeepCopy(list [][][][]string) [][][][]string

StringD4DeepCopy makes a deep copy of the given list. The copy is returned.

func StringD5

func StringD5(list [][][][][]string) [][][][][]string

StringD5 makes a shallow copy of the given list. The copy is returned.

func StringD5DeepCopy

func StringD5DeepCopy(list [][][][][]string) [][][][][]string

StringD5DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt

func UInt(list []uint) []uint

UInt makes a copy of the given list. The copy is returned.

func UInt16

func UInt16(list []uint16) []uint16

UInt16 makes a copy of the given list. The copy is returned.

func UInt16D2

func UInt16D2(list [][]uint16) [][]uint16

UInt16D2 makes a shallow copy of the given list. The copy is returned.

func UInt16D2DeepCopy

func UInt16D2DeepCopy(list [][]uint16) [][]uint16

UInt16D2DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt16D3

func UInt16D3(list [][][]uint16) [][][]uint16

UInt16D3 makes a shallow copy of the given list. The copy is returned.

func UInt16D3DeepCopy

func UInt16D3DeepCopy(list [][][]uint16) [][][]uint16

UInt16D3DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt16D4

func UInt16D4(list [][][][]uint16) [][][][]uint16

UInt16D4 makes a shallow copy of the given list. The copy is returned.

func UInt16D4DeepCopy

func UInt16D4DeepCopy(list [][][][]uint16) [][][][]uint16

UInt16D4DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt16D5

func UInt16D5(list [][][][][]uint16) [][][][][]uint16

UInt16D5 makes a shallow copy of the given list. The copy is returned.

func UInt16D5DeepCopy

func UInt16D5DeepCopy(list [][][][][]uint16) [][][][][]uint16

UInt16D5DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt32

func UInt32(list []uint32) []uint32

UInt32 makes a copy of the given list. The copy is returned.

func UInt32D2

func UInt32D2(list [][]uint32) [][]uint32

UInt32D2 makes a shallow copy of the given list. The copy is returned.

func UInt32D2DeepCopy

func UInt32D2DeepCopy(list [][]uint32) [][]uint32

UInt32D2DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt32D3

func UInt32D3(list [][][]uint32) [][][]uint32

UInt32D3 makes a shallow copy of the given list. The copy is returned.

func UInt32D3DeepCopy

func UInt32D3DeepCopy(list [][][]uint32) [][][]uint32

UInt32D3DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt32D4

func UInt32D4(list [][][][]uint32) [][][][]uint32

UInt32D4 makes a shallow copy of the given list. The copy is returned.

func UInt32D4DeepCopy

func UInt32D4DeepCopy(list [][][][]uint32) [][][][]uint32

UInt32D4DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt32D5

func UInt32D5(list [][][][][]uint32) [][][][][]uint32

UInt32D5 makes a shallow copy of the given list. The copy is returned.

func UInt32D5DeepCopy

func UInt32D5DeepCopy(list [][][][][]uint32) [][][][][]uint32

UInt32D5DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt64

func UInt64(list []uint64) []uint64

UInt64 makes a copy of the given list. The copy is returned.

func UInt64D2

func UInt64D2(list [][]uint64) [][]uint64

UInt64D2 makes a shallow copy of the given list. The copy is returned.

func UInt64D2DeepCopy

func UInt64D2DeepCopy(list [][]uint64) [][]uint64

UInt64D2DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt64D3

func UInt64D3(list [][][]uint64) [][][]uint64

UInt64D3 makes a shallow copy of the given list. The copy is returned.

func UInt64D3DeepCopy

func UInt64D3DeepCopy(list [][][]uint64) [][][]uint64

UInt64D3DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt64D4

func UInt64D4(list [][][][]uint64) [][][][]uint64

UInt64D4 makes a shallow copy of the given list. The copy is returned.

func UInt64D4DeepCopy

func UInt64D4DeepCopy(list [][][][]uint64) [][][][]uint64

UInt64D4DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt64D5

func UInt64D5(list [][][][][]uint64) [][][][][]uint64

UInt64D5 makes a shallow copy of the given list. The copy is returned.

func UInt64D5DeepCopy

func UInt64D5DeepCopy(list [][][][][]uint64) [][][][][]uint64

UInt64D5DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt8

func UInt8(list []uint8) []uint8

UInt8 makes a copy of the given list. The copy is returned.

func UInt8D2

func UInt8D2(list [][]uint8) [][]uint8

UInt8D2 makes a shallow copy of the given list. The copy is returned.

func UInt8D2DeepCopy

func UInt8D2DeepCopy(list [][]uint8) [][]uint8

UInt8D2DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt8D3

func UInt8D3(list [][][]uint8) [][][]uint8

UInt8D3 makes a shallow copy of the given list. The copy is returned.

func UInt8D3DeepCopy

func UInt8D3DeepCopy(list [][][]uint8) [][][]uint8

UInt8D3DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt8D4

func UInt8D4(list [][][][]uint8) [][][][]uint8

UInt8D4 makes a shallow copy of the given list. The copy is returned.

func UInt8D4DeepCopy

func UInt8D4DeepCopy(list [][][][]uint8) [][][][]uint8

UInt8D4DeepCopy makes a deep copy of the given list. The copy is returned.

func UInt8D5

func UInt8D5(list [][][][][]uint8) [][][][][]uint8

UInt8D5 makes a shallow copy of the given list. The copy is returned.

func UInt8D5DeepCopy

func UInt8D5DeepCopy(list [][][][][]uint8) [][][][][]uint8

UInt8D5DeepCopy makes a deep copy of the given list. The copy is returned.

func UIntD2

func UIntD2(list [][]uint) [][]uint

UIntD2 makes a shallow copy of the given list. The copy is returned.

func UIntD2DeepCopy

func UIntD2DeepCopy(list [][]uint) [][]uint

UIntD2DeepCopy makes a deep copy of the given list. The copy is returned.

func UIntD3

func UIntD3(list [][][]uint) [][][]uint

UIntD3 makes a shallow copy of the given list. The copy is returned.

func UIntD3DeepCopy

func UIntD3DeepCopy(list [][][]uint) [][][]uint

UIntD3DeepCopy makes a deep copy of the given list. The copy is returned.

func UIntD4

func UIntD4(list [][][][]uint) [][][][]uint

UIntD4 makes a shallow copy of the given list. The copy is returned.

func UIntD4DeepCopy

func UIntD4DeepCopy(list [][][][]uint) [][][][]uint

UIntD4DeepCopy makes a deep copy of the given list. The copy is returned.

func UIntD5

func UIntD5(list [][][][][]uint) [][][][][]uint

UIntD5 makes a shallow copy of the given list. The copy is returned.

func UIntD5DeepCopy

func UIntD5DeepCopy(list [][][][][]uint) [][][][][]uint

UIntD5DeepCopy makes a deep copy of the given list. The copy is returned.

func UIntPtr

func UIntPtr(list []uintptr) []uintptr

UIntPtr makes a copy of the given list. The copy is returned.

func UIntPtrD2

func UIntPtrD2(list [][]uintptr) [][]uintptr

UIntPtrD2 makes a shallow copy of the given list. The copy is returned.

func UIntPtrD2DeepCopy

func UIntPtrD2DeepCopy(list [][]uintptr) [][]uintptr

UIntPtrD2DeepCopy makes a deep copy of the given list. The copy is returned.

func UIntPtrD3

func UIntPtrD3(list [][][]uintptr) [][][]uintptr

UIntPtrD3 makes a shallow copy of the given list. The copy is returned.

func UIntPtrD3DeepCopy

func UIntPtrD3DeepCopy(list [][][]uintptr) [][][]uintptr

UIntPtrD3DeepCopy makes a deep copy of the given list. The copy is returned.

func UIntPtrD4

func UIntPtrD4(list [][][][]uintptr) [][][][]uintptr

UIntPtrD4 makes a shallow copy of the given list. The copy is returned.

func UIntPtrD4DeepCopy

func UIntPtrD4DeepCopy(list [][][][]uintptr) [][][][]uintptr

UIntPtrD4DeepCopy makes a deep copy of the given list. The copy is returned.

func UIntPtrD5

func UIntPtrD5(list [][][][][]uintptr) [][][][][]uintptr

UIntPtrD5 makes a shallow copy of the given list. The copy is returned.

func UIntPtrD5DeepCopy

func UIntPtrD5DeepCopy(list [][][][][]uintptr) [][][][][]uintptr

UIntPtrD5DeepCopy makes a deep copy of the given list. The copy is returned.

Types

This section is empty.

Jump to