contains

package module
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2022 License: BSL-1.0 Imports: 2 Imported by: 0

README

contains

GoDoc

About

This package provides the function "contains" for slices of basic types. It is published on https://github.com/vbsw/slices/contains and https://gitlab.com/vbsw/slices/contains.

Copyright 2018, 2020, 2021, 2022, Vitali Baumtrok (vbsw@mailbox.org).

contains is distributed under the Boost Software License, version 1.0. (See accompanying file LICENSE or copy at http://www.boost.org/LICENSE_1_0.txt)

contains is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the Boost Software License for more details.

References

Documentation

Overview

Package contains provides the "contains" function for slices of basic types.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Bool

func Bool(list []bool, value bool) bool

Bool returns true, if list contains value.

func BoolD2

func BoolD2(list [][]bool, value bool) bool

BoolD2 returns true, if list contains value.

func BoolD3

func BoolD3(list [][][]bool, value bool) bool

BoolD3 returns true, if list contains value.

func BoolD4

func BoolD4(list [][][][]bool, value bool) bool

BoolD4 returns true, if list contains value.

func BoolD5

func BoolD5(list [][][][][]bool, value bool) bool

BoolD5 returns true, if list contains value.

func Byte

func Byte(list []byte, value byte) bool

Byte returns true, if list contains value.

func ByteD2

func ByteD2(list [][]byte, value byte) bool

ByteD2 returns true, if list contains value.

func ByteD3

func ByteD3(list [][][]byte, value byte) bool

ByteD3 returns true, if list contains value.

func ByteD4

func ByteD4(list [][][][]byte, value byte) bool

ByteD4 returns true, if list contains value.

func ByteD5

func ByteD5(list [][][][][]byte, value byte) bool

ByteD5 returns true, if list contains value.

func Bytes

func Bytes(list []byte, sequence []byte) bool

Bytes returns true, if list contains sequence. (Same as standard function bytes.Contains.)

func Bytes2D

func Bytes2D(list [][]byte, sequence []byte) bool

Bytes2D returns true, if list contains sequence.

func Bytes3D

func Bytes3D(list [][][]byte, sequence []byte) bool

Bytes3D returns true, if list contains sequence.

func Bytes4D

func Bytes4D(list [][][][]byte, sequence []byte) bool

Bytes4D returns true, if list contains sequence.

func Bytes5D

func Bytes5D(list [][][][][]byte, sequence []byte) bool

Bytes5D returns true, if list contains sequence.

func Complex128

func Complex128(list []complex128, value complex128) bool

Complex128 returns true, if list contains value.

func Complex128D2

func Complex128D2(list [][]complex128, value complex128) bool

Complex128D2 returns true, if list contains value.

func Complex128D3

func Complex128D3(list [][][]complex128, value complex128) bool

Complex128D3 returns true, if list contains value.

func Complex128D4

func Complex128D4(list [][][][]complex128, value complex128) bool

Complex128D4 returns true, if list contains value.

func Complex128D5

func Complex128D5(list [][][][][]complex128, value complex128) bool

Complex128D5 returns true, if list contains value.

func Complex64

func Complex64(list []complex64, value complex64) bool

Complex64 returns true, if list contains value.

func Complex64D2

func Complex64D2(list [][]complex64, value complex64) bool

Complex64D2 returns true, if list contains value.

func Complex64D3

func Complex64D3(list [][][]complex64, value complex64) bool

Complex64D3 returns true, if list contains value.

func Complex64D4

func Complex64D4(list [][][][]complex64, value complex64) bool

Complex64D4 returns true, if list contains value.

func Complex64D5

func Complex64D5(list [][][][][]complex64, value complex64) bool

Complex64D5 returns true, if list contains value.

func Error

func Error(list []error, value error) bool

Error returns true, if list contains value.

func ErrorD2

func ErrorD2(list [][]error, value error) bool

ErrorD2 returns true, if list contains value.

func ErrorD3

func ErrorD3(list [][][]error, value error) bool

ErrorD3 returns true, if list contains value.

func ErrorD4

func ErrorD4(list [][][][]error, value error) bool

ErrorD4 returns true, if list contains value.

func ErrorD5

func ErrorD5(list [][][][][]error, value error) bool

ErrorD5 returns true, if list contains value.

func Float32

func Float32(list []float32, value float32) bool

Float32 returns true, if list contains value.

func Float32D2

func Float32D2(list [][]float32, value float32) bool

Float32D2 returns true, if list contains value.

func Float32D3

func Float32D3(list [][][]float32, value float32) bool

Float32D3 returns true, if list contains value.

func Float32D4

func Float32D4(list [][][][]float32, value float32) bool

Float32D4 returns true, if list contains value.

func Float32D5

func Float32D5(list [][][][][]float32, value float32) bool

Float32D5 returns true, if list contains value.

func Float64

func Float64(list []float64, value float64) bool

Float64 returns true, if list contains value.

func Float64D2

func Float64D2(list [][]float64, value float64) bool

Float64D2 returns true, if list contains value.

func Float64D3

func Float64D3(list [][][]float64, value float64) bool

Float64D3 returns true, if list contains value.

func Float64D4

func Float64D4(list [][][][]float64, value float64) bool

Float64D4 returns true, if list contains value.

func Float64D5

func Float64D5(list [][][][][]float64, value float64) bool

Float64D5 returns true, if list contains value.

func Int

func Int(list []int, value int) bool

Int returns true, if list contains value.

func Int16

func Int16(list []int16, value int16) bool

Int16 returns true, if list contains value.

func Int16D2

func Int16D2(list [][]int16, value int16) bool

Int16D2 returns true, if list contains value.

func Int16D3

func Int16D3(list [][][]int16, value int16) bool

Int16D3 returns true, if list contains value.

func Int16D4

func Int16D4(list [][][][]int16, value int16) bool

Int16D4 returns true, if list contains value.

func Int16D5

func Int16D5(list [][][][][]int16, value int16) bool

Int16D5 returns true, if list contains value.

func Int32

func Int32(list []int32, value int32) bool

Int32 returns true, if list contains value.

func Int32D2

func Int32D2(list [][]int32, value int32) bool

Int32D2 returns true, if list contains value.

func Int32D3

func Int32D3(list [][][]int32, value int32) bool

Int32D3 returns true, if list contains value.

func Int32D4

func Int32D4(list [][][][]int32, value int32) bool

Int32D4 returns true, if list contains value.

func Int32D5

func Int32D5(list [][][][][]int32, value int32) bool

Int32D5 returns true, if list contains value.

func Int64

func Int64(list []int64, value int64) bool

Int64 returns true, if list contains value.

func Int64D2

func Int64D2(list [][]int64, value int64) bool

Int64D2 returns true, if list contains value.

func Int64D3

func Int64D3(list [][][]int64, value int64) bool

Int64D3 returns true, if list contains value.

func Int64D4

func Int64D4(list [][][][]int64, value int64) bool

Int64D4 returns true, if list contains value.

func Int64D5

func Int64D5(list [][][][][]int64, value int64) bool

Int64D5 returns true, if list contains value.

func Int8

func Int8(list []int8, value int8) bool

Int8 returns true, if list contains value.

func Int8D2

func Int8D2(list [][]int8, value int8) bool

Int8D2 returns true, if list contains value.

func Int8D3

func Int8D3(list [][][]int8, value int8) bool

Int8D3 returns true, if list contains value.

func Int8D4

func Int8D4(list [][][][]int8, value int8) bool

Int8D4 returns true, if list contains value.

func Int8D5

func Int8D5(list [][][][][]int8, value int8) bool

Int8D5 returns true, if list contains value.

func IntD2

func IntD2(list [][]int, value int) bool

IntD2 returns true, if list contains value.

func IntD3

func IntD3(list [][][]int, value int) bool

IntD3 returns true, if list contains value.

func IntD4

func IntD4(list [][][][]int, value int) bool

IntD4 returns true, if list contains value.

func IntD5

func IntD5(list [][][][][]int, value int) bool

IntD5 returns true, if list contains value.

func Interface

func Interface(list []interface{}, value interface{}) bool

Interface returns true, if list contains value.

func InterfaceD2

func InterfaceD2(list [][]interface{}, value interface{}) bool

InterfaceD2 returns true, if list contains value.

func InterfaceD3

func InterfaceD3(list [][][]interface{}, value interface{}) bool

InterfaceD3 returns true, if list contains value.

func InterfaceD4

func InterfaceD4(list [][][][]interface{}, value interface{}) bool

InterfaceD4 returns true, if list contains value.

func InterfaceD5

func InterfaceD5(list [][][][][]interface{}, value interface{}) bool

InterfaceD5 returns true, if list contains value.

func Pointer

func Pointer(list []unsafe.Pointer, value unsafe.Pointer) bool

Pointer returns true, if list contains value.

func PointerD2

func PointerD2(list [][]unsafe.Pointer, value unsafe.Pointer) bool

PointerD2 returns true, if list contains value.

func PointerD3

func PointerD3(list [][][]unsafe.Pointer, value unsafe.Pointer) bool

PointerD3 returns true, if list contains value.

func PointerD4

func PointerD4(list [][][][]unsafe.Pointer, value unsafe.Pointer) bool

PointerD4 returns true, if list contains value.

func PointerD5

func PointerD5(list [][][][][]unsafe.Pointer, value unsafe.Pointer) bool

PointerD5 returns true, if list contains value.

func Rune

func Rune(list []rune, value rune) bool

Rune returns true, if list contains value.

func RuneD2

func RuneD2(list [][]rune, value rune) bool

RuneD2 returns true, if list contains value.

func RuneD3

func RuneD3(list [][][]rune, value rune) bool

RuneD3 returns true, if list contains value.

func RuneD4

func RuneD4(list [][][][]rune, value rune) bool

RuneD4 returns true, if list contains value.

func RuneD5

func RuneD5(list [][][][][]rune, value rune) bool

RuneD5 returns true, if list contains value.

func String

func String(list []string, value string) bool

String returns true, if list contains value.

func StringD2

func StringD2(list [][]string, value string) bool

StringD2 returns true, if list contains value.

func StringD3

func StringD3(list [][][]string, value string) bool

StringD3 returns true, if list contains value.

func StringD4

func StringD4(list [][][][]string, value string) bool

StringD4 returns true, if list contains value.

func StringD5

func StringD5(list [][][][][]string, value string) bool

StringD5 returns true, if list contains value.

func UInt

func UInt(list []uint, value uint) bool

UInt returns true, if list contains value.

func UInt16

func UInt16(list []uint16, value uint16) bool

UInt16 returns true, if list contains value.

func UInt16D2

func UInt16D2(list [][]uint16, value uint16) bool

UInt16D2 returns true, if list contains value.

func UInt16D3

func UInt16D3(list [][][]uint16, value uint16) bool

UInt16D3 returns true, if list contains value.

func UInt16D4

func UInt16D4(list [][][][]uint16, value uint16) bool

UInt16D4 returns true, if list contains value.

func UInt16D5

func UInt16D5(list [][][][][]uint16, value uint16) bool

UInt16D5 returns true, if list contains value.

func UInt32

func UInt32(list []uint32, value uint32) bool

UInt32 returns true, if list contains value.

func UInt32D2

func UInt32D2(list [][]uint32, value uint32) bool

UInt32D2 returns true, if list contains value.

func UInt32D3

func UInt32D3(list [][][]uint32, value uint32) bool

UInt32D3 returns true, if list contains value.

func UInt32D4

func UInt32D4(list [][][][]uint32, value uint32) bool

UInt32D4 returns true, if list contains value.

func UInt32D5

func UInt32D5(list [][][][][]uint32, value uint32) bool

UInt32D5 returns true, if list contains value.

func UInt64

func UInt64(list []uint64, value uint64) bool

UInt64 returns true, if list contains value.

func UInt64D2

func UInt64D2(list [][]uint64, value uint64) bool

UInt64D2 returns true, if list contains value.

func UInt64D3

func UInt64D3(list [][][]uint64, value uint64) bool

UInt64D3 returns true, if list contains value.

func UInt64D4

func UInt64D4(list [][][][]uint64, value uint64) bool

UInt64D4 returns true, if list contains value.

func UInt64D5

func UInt64D5(list [][][][][]uint64, value uint64) bool

UInt64D5 returns true, if list contains value.

func UInt8

func UInt8(list []uint8, value uint8) bool

UInt8 returns true, if list contains value.

func UInt8D2

func UInt8D2(list [][]uint8, value uint8) bool

UInt8D2 returns true, if list contains value.

func UInt8D3

func UInt8D3(list [][][]uint8, value uint8) bool

UInt8D3 returns true, if list contains value.

func UInt8D4

func UInt8D4(list [][][][]uint8, value uint8) bool

UInt8D4 returns true, if list contains value.

func UInt8D5

func UInt8D5(list [][][][][]uint8, value uint8) bool

UInt8D5 returns true, if list contains value.

func UIntD2

func UIntD2(list [][]uint, value uint) bool

UIntD2 returns true, if list contains value.

func UIntD3

func UIntD3(list [][][]uint, value uint) bool

UIntD3 returns true, if list contains value.

func UIntD4

func UIntD4(list [][][][]uint, value uint) bool

UIntD4 returns true, if list contains value.

func UIntD5

func UIntD5(list [][][][][]uint, value uint) bool

UIntD5 returns true, if list contains value.

func UIntPtr

func UIntPtr(list []uintptr, value uintptr) bool

UIntPtr returns true, if list contains value.

func UIntPtrD2

func UIntPtrD2(list [][]uintptr, value uintptr) bool

UIntPtrD2 returns true, if list contains value.

func UIntPtrD3

func UIntPtrD3(list [][][]uintptr, value uintptr) bool

UIntPtrD3 returns true, if list contains value.

func UIntPtrD4

func UIntPtrD4(list [][][][]uintptr, value uintptr) bool

UIntPtrD4 returns true, if list contains value.

func UIntPtrD5

func UIntPtrD5(list [][][][][]uintptr, value uintptr) bool

UIntPtrD5 returns true, if list contains value.

Types

This section is empty.

Jump to