count

package module
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 3, 2022 License: BSL-1.0 Imports: 1 Imported by: 1

README

count

GoDoc

About

This package provides the function "count" for slices of basic types. It is published on https://github.com/vbsw/slices/count and https://gitlab.com/vbsw/slices/count.

Copyright 2019, 2020, 2022, Vitali Baumtrok (vbsw@mailbox.org).

count is distributed under the Boost Software License, version 1.0. (See accompanying file LICENSE or copy at http://www.boost.org/LICENSE_1_0.txt)

count is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the Boost Software License for more details.

References

Documentation

Overview

Package count provides the "count" function for slices of basic types.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Bool

func Bool(list []bool, value bool) int

Bool returns count of value in list.

func BoolD2

func BoolD2(list [][]bool, value bool) int

BoolD2 returns count of value in list.

func BoolD3

func BoolD3(list [][][]bool, value bool) int

BoolD3 returns count of value in list.

func BoolD4

func BoolD4(list [][][][]bool, value bool) int

BoolD4 returns count of value in list.

func BoolD5

func BoolD5(list [][][][][]bool, value bool) int

BoolD5 returns count of value in list.

func Byte

func Byte(list []byte, value byte) int

Byte returns count of value in list.

func ByteD2

func ByteD2(list [][]byte, value byte) int

ByteD2 returns count of value in list.

func ByteD3

func ByteD3(list [][][]byte, value byte) int

ByteD3 returns count of value in list.

func ByteD4

func ByteD4(list [][][][]byte, value byte) int

ByteD4 returns count of value in list.

func ByteD5

func ByteD5(list [][][][][]byte, value byte) int

ByteD5 returns count of value in list.

func Complex128

func Complex128(list []complex128, value complex128) int

Complex128 returns count of value in list.

func Complex128D2

func Complex128D2(list [][]complex128, value complex128) int

Complex128D2 returns count of value in list.

func Complex128D3

func Complex128D3(list [][][]complex128, value complex128) int

Complex128D3 returns count of value in list.

func Complex128D4

func Complex128D4(list [][][][]complex128, value complex128) int

Complex128D4 returns count of value in list.

func Complex128D5

func Complex128D5(list [][][][][]complex128, value complex128) int

Complex128D5 returns count of value in list.

func Complex64

func Complex64(list []complex64, value complex64) int

Complex64 returns count of value in list.

func Complex64D2

func Complex64D2(list [][]complex64, value complex64) int

Complex64D2 returns count of value in list.

func Complex64D3

func Complex64D3(list [][][]complex64, value complex64) int

Complex64D3 returns count of value in list.

func Complex64D4

func Complex64D4(list [][][][]complex64, value complex64) int

Complex64D4 returns count of value in list.

func Complex64D5

func Complex64D5(list [][][][][]complex64, value complex64) int

Complex64D5 returns count of value in list.

func Error

func Error(list []error, value error) int

Error returns count of value in list.

func ErrorD2

func ErrorD2(list [][]error, value error) int

ErrorD2 returns count of value in list.

func ErrorD3

func ErrorD3(list [][][]error, value error) int

ErrorD3 returns count of value in list.

func ErrorD4

func ErrorD4(list [][][][]error, value error) int

ErrorD4 returns count of value in list.

func ErrorD5

func ErrorD5(list [][][][][]error, value error) int

ErrorD5 returns count of value in list.

func Float32

func Float32(list []float32, value float32) int

Float32 returns count of value in list.

func Float32D2

func Float32D2(list [][]float32, value float32) int

Float32D2 returns count of value in list.

func Float32D3

func Float32D3(list [][][]float32, value float32) int

Float32D3 returns count of value in list.

func Float32D4

func Float32D4(list [][][][]float32, value float32) int

Float32D4 returns count of value in list.

func Float32D5

func Float32D5(list [][][][][]float32, value float32) int

Float32D5 returns count of value in list.

func Float64

func Float64(list []float64, value float64) int

Float64 returns count of value in list.

func Float64D2

func Float64D2(list [][]float64, value float64) int

Float64D2 returns count of value in list.

func Float64D3

func Float64D3(list [][][]float64, value float64) int

Float64D3 returns count of value in list.

func Float64D4

func Float64D4(list [][][][]float64, value float64) int

Float64D4 returns count of value in list.

func Float64D5

func Float64D5(list [][][][][]float64, value float64) int

Float64D5 returns count of value in list.

func Int

func Int(list []int, value int) int

Int returns count of value in list.

func Int16

func Int16(list []int16, value int16) int

Int16 returns count of value in list.

func Int16D2

func Int16D2(list [][]int16, value int16) int

Int16D2 returns count of value in list.

func Int16D3

func Int16D3(list [][][]int16, value int16) int

Int16D3 returns count of value in list.

func Int16D4

func Int16D4(list [][][][]int16, value int16) int

Int16D4 returns count of value in list.

func Int16D5

func Int16D5(list [][][][][]int16, value int16) int

Int16D5 returns count of value in list.

func Int32

func Int32(list []int32, value int32) int

Int32 returns count of value in list.

func Int32D2

func Int32D2(list [][]int32, value int32) int

Int32D2 returns count of value in list.

func Int32D3

func Int32D3(list [][][]int32, value int32) int

Int32D3 returns count of value in list.

func Int32D4

func Int32D4(list [][][][]int32, value int32) int

Int32D4 returns count of value in list.

func Int32D5

func Int32D5(list [][][][][]int32, value int32) int

Int32D5 returns count of value in list.

func Int64

func Int64(list []int64, value int64) int

Int64 returns count of value in list.

func Int64D2

func Int64D2(list [][]int64, value int64) int

Int64D2 returns count of value in list.

func Int64D3

func Int64D3(list [][][]int64, value int64) int

Int64D3 returns count of value in list.

func Int64D4

func Int64D4(list [][][][]int64, value int64) int

Int64D4 returns count of value in list.

func Int64D5

func Int64D5(list [][][][][]int64, value int64) int

Int64D5 returns count of value in list.

func Int8

func Int8(list []int8, value int8) int

Int8 returns count of value in list.

func Int8D2

func Int8D2(list [][]int8, value int8) int

Int8D2 returns count of value in list.

func Int8D3

func Int8D3(list [][][]int8, value int8) int

Int8D3 returns count of value in list.

func Int8D4

func Int8D4(list [][][][]int8, value int8) int

Int8D4 returns count of value in list.

func Int8D5

func Int8D5(list [][][][][]int8, value int8) int

Int8D5 returns count of value in list.

func IntD2

func IntD2(list [][]int, value int) int

IntD2 returns count of value in list.

func IntD3

func IntD3(list [][][]int, value int) int

IntD3 returns count of value in list.

func IntD4

func IntD4(list [][][][]int, value int) int

IntD4 returns count of value in list.

func IntD5

func IntD5(list [][][][][]int, value int) int

IntD5 returns count of value in list.

func Interface

func Interface(list []interface{}, value interface{}) int

Interface returns count of value in list.

func InterfaceD2

func InterfaceD2(list [][]interface{}, value interface{}) int

InterfaceD2 returns count of value in list.

func InterfaceD3

func InterfaceD3(list [][][]interface{}, value interface{}) int

InterfaceD3 returns count of value in list.

func InterfaceD4

func InterfaceD4(list [][][][]interface{}, value interface{}) int

InterfaceD4 returns count of value in list.

func InterfaceD5

func InterfaceD5(list [][][][][]interface{}, value interface{}) int

InterfaceD5 returns count of value in list.

func Pointer

func Pointer(list []unsafe.Pointer, value unsafe.Pointer) int

Pointer returns count of value in list.

func PointerD2

func PointerD2(list [][]unsafe.Pointer, value unsafe.Pointer) int

PointerD2 returns count of value in list.

func PointerD3

func PointerD3(list [][][]unsafe.Pointer, value unsafe.Pointer) int

PointerD3 returns count of value in list.

func PointerD4

func PointerD4(list [][][][]unsafe.Pointer, value unsafe.Pointer) int

PointerD4 returns count of value in list.

func PointerD5

func PointerD5(list [][][][][]unsafe.Pointer, value unsafe.Pointer) int

PointerD5 returns count of value in list.

func Rune

func Rune(list []rune, value rune) int

Rune returns count of value in list.

func RuneD2

func RuneD2(list [][]rune, value rune) int

RuneD2 returns count of value in list.

func RuneD3

func RuneD3(list [][][]rune, value rune) int

RuneD3 returns count of value in list.

func RuneD4

func RuneD4(list [][][][]rune, value rune) int

RuneD4 returns count of value in list.

func RuneD5

func RuneD5(list [][][][][]rune, value rune) int

RuneD5 returns count of value in list.

func String

func String(list []string, value string) int

String returns count of value in list.

func StringD2

func StringD2(list [][]string, value string) int

StringD2 returns count of value in list.

func StringD3

func StringD3(list [][][]string, value string) int

StringD3 returns count of value in list.

func StringD4

func StringD4(list [][][][]string, value string) int

StringD4 returns count of value in list.

func StringD5

func StringD5(list [][][][][]string, value string) int

StringD5 returns count of value in list.

func UInt

func UInt(list []uint, value uint) int

UInt returns count of value in list.

func UInt16

func UInt16(list []uint16, value uint16) int

UInt16 returns count of value in list.

func UInt16D2

func UInt16D2(list [][]uint16, value uint16) int

UInt16D2 returns count of value in list.

func UInt16D3

func UInt16D3(list [][][]uint16, value uint16) int

UInt16D3 returns count of value in list.

func UInt16D4

func UInt16D4(list [][][][]uint16, value uint16) int

UInt16D4 returns count of value in list.

func UInt16D5

func UInt16D5(list [][][][][]uint16, value uint16) int

UInt16D5 returns count of value in list.

func UInt32

func UInt32(list []uint32, value uint32) int

UInt32 returns count of value in list.

func UInt32D2

func UInt32D2(list [][]uint32, value uint32) int

UInt32D2 returns count of value in list.

func UInt32D3

func UInt32D3(list [][][]uint32, value uint32) int

UInt32D3 returns count of value in list.

func UInt32D4

func UInt32D4(list [][][][]uint32, value uint32) int

UInt32D4 returns count of value in list.

func UInt32D5

func UInt32D5(list [][][][][]uint32, value uint32) int

UInt32D5 returns count of value in list.

func UInt64

func UInt64(list []uint64, value uint64) int

UInt64 returns count of value in list.

func UInt64D2

func UInt64D2(list [][]uint64, value uint64) int

UInt64D2 returns count of value in list.

func UInt64D3

func UInt64D3(list [][][]uint64, value uint64) int

UInt64D3 returns count of value in list.

func UInt64D4

func UInt64D4(list [][][][]uint64, value uint64) int

UInt64D4 returns count of value in list.

func UInt64D5

func UInt64D5(list [][][][][]uint64, value uint64) int

UInt64D5 returns count of value in list.

func UInt8

func UInt8(list []uint8, value uint8) int

UInt8 returns count of value in list.

func UInt8D2

func UInt8D2(list [][]uint8, value uint8) int

UInt8D2 returns count of value in list.

func UInt8D3

func UInt8D3(list [][][]uint8, value uint8) int

UInt8D3 returns count of value in list.

func UInt8D4

func UInt8D4(list [][][][]uint8, value uint8) int

UInt8D4 returns count of value in list.

func UInt8D5

func UInt8D5(list [][][][][]uint8, value uint8) int

UInt8D5 returns count of value in list.

func UIntD2

func UIntD2(list [][]uint, value uint) int

UIntD2 returns count of value in list.

func UIntD3

func UIntD3(list [][][]uint, value uint) int

UIntD3 returns count of value in list.

func UIntD4

func UIntD4(list [][][][]uint, value uint) int

UIntD4 returns count of value in list.

func UIntD5

func UIntD5(list [][][][][]uint, value uint) int

UIntD5 returns count of value in list.

func UIntPtr

func UIntPtr(list []uintptr, value uintptr) int

UIntPtr returns count of value in list.

func UIntPtrD2

func UIntPtrD2(list [][]uintptr, value uintptr) int

UIntPtrD2 returns count of value in list.

func UIntPtrD3

func UIntPtrD3(list [][][]uintptr, value uintptr) int

UIntPtrD3 returns count of value in list.

func UIntPtrD4

func UIntPtrD4(list [][][][]uintptr, value uintptr) int

UIntPtrD4 returns count of value in list.

func UIntPtrD5

func UIntPtrD5(list [][][][][]uintptr, value uintptr) int

UIntPtrD5 returns count of value in list.

Types

This section is empty.

Jump to