Documentation
¶
Overview ¶
Package clone provides the "clone" function for slices of basic types.
Index ¶
- func Bool(list []bool) []bool
- func BoolD2(list [][]bool) [][]bool
- func BoolD2DeepCopy(list [][]bool) [][]bool
- func BoolD3(list [][][]bool) [][][]bool
- func BoolD3DeepCopy(list [][][]bool) [][][]bool
- func BoolD4(list [][][][]bool) [][][][]bool
- func BoolD4DeepCopy(list [][][][]bool) [][][][]bool
- func BoolD5(list [][][][][]bool) [][][][][]bool
- func BoolD5DeepCopy(list [][][][][]bool) [][][][][]bool
- func Byte(list []byte) []byte
- func ByteD2(list [][]byte) [][]byte
- func ByteD2DeepCopy(list [][]byte) [][]byte
- func ByteD3(list [][][]byte) [][][]byte
- func ByteD3DeepCopy(list [][][]byte) [][][]byte
- func ByteD4(list [][][][]byte) [][][][]byte
- func ByteD4DeepCopy(list [][][][]byte) [][][][]byte
- func ByteD5(list [][][][][]byte) [][][][][]byte
- func ByteD5DeepCopy(list [][][][][]byte) [][][][][]byte
- func Complex128(list []complex128) []complex128
- func Complex128D2(list [][]complex128) [][]complex128
- func Complex128D2DeepCopy(list [][]complex128) [][]complex128
- func Complex128D3(list [][][]complex128) [][][]complex128
- func Complex128D3DeepCopy(list [][][]complex128) [][][]complex128
- func Complex128D4(list [][][][]complex128) [][][][]complex128
- func Complex128D4DeepCopy(list [][][][]complex128) [][][][]complex128
- func Complex128D5(list [][][][][]complex128) [][][][][]complex128
- func Complex128D5DeepCopy(list [][][][][]complex128) [][][][][]complex128
- func Complex64(list []complex64) []complex64
- func Complex64D2(list [][]complex64) [][]complex64
- func Complex64D2DeepCopy(list [][]complex64) [][]complex64
- func Complex64D3(list [][][]complex64) [][][]complex64
- func Complex64D3DeepCopy(list [][][]complex64) [][][]complex64
- func Complex64D4(list [][][][]complex64) [][][][]complex64
- func Complex64D4DeepCopy(list [][][][]complex64) [][][][]complex64
- func Complex64D5(list [][][][][]complex64) [][][][][]complex64
- func Complex64D5DeepCopy(list [][][][][]complex64) [][][][][]complex64
- func Error(list []error) []error
- func ErrorD2(list [][]error) [][]error
- func ErrorD2DeepCopy(list [][]error) [][]error
- func ErrorD3(list [][][]error) [][][]error
- func ErrorD3DeepCopy(list [][][]error) [][][]error
- func ErrorD4(list [][][][]error) [][][][]error
- func ErrorD4DeepCopy(list [][][][]error) [][][][]error
- func ErrorD5(list [][][][][]error) [][][][][]error
- func ErrorD5DeepCopy(list [][][][][]error) [][][][][]error
- func Float32(list []float32) []float32
- func Float32D2(list [][]float32) [][]float32
- func Float32D2DeepCopy(list [][]float32) [][]float32
- func Float32D3(list [][][]float32) [][][]float32
- func Float32D3DeepCopy(list [][][]float32) [][][]float32
- func Float32D4(list [][][][]float32) [][][][]float32
- func Float32D4DeepCopy(list [][][][]float32) [][][][]float32
- func Float32D5(list [][][][][]float32) [][][][][]float32
- func Float32D5DeepCopy(list [][][][][]float32) [][][][][]float32
- func Float64(list []float64) []float64
- func Float64D2(list [][]float64) [][]float64
- func Float64D2DeepCopy(list [][]float64) [][]float64
- func Float64D3(list [][][]float64) [][][]float64
- func Float64D3DeepCopy(list [][][]float64) [][][]float64
- func Float64D4(list [][][][]float64) [][][][]float64
- func Float64D4DeepCopy(list [][][][]float64) [][][][]float64
- func Float64D5(list [][][][][]float64) [][][][][]float64
- func Float64D5DeepCopy(list [][][][][]float64) [][][][][]float64
- func Int(list []int) []int
- func Int16(list []int16) []int16
- func Int16D2(list [][]int16) [][]int16
- func Int16D2DeepCopy(list [][]int16) [][]int16
- func Int16D3(list [][][]int16) [][][]int16
- func Int16D3DeepCopy(list [][][]int16) [][][]int16
- func Int16D4(list [][][][]int16) [][][][]int16
- func Int16D4DeepCopy(list [][][][]int16) [][][][]int16
- func Int16D5(list [][][][][]int16) [][][][][]int16
- func Int16D5DeepCopy(list [][][][][]int16) [][][][][]int16
- func Int32(list []int32) []int32
- func Int32D2(list [][]int32) [][]int32
- func Int32D2DeepCopy(list [][]int32) [][]int32
- func Int32D3(list [][][]int32) [][][]int32
- func Int32D3DeepCopy(list [][][]int32) [][][]int32
- func Int32D4(list [][][][]int32) [][][][]int32
- func Int32D4DeepCopy(list [][][][]int32) [][][][]int32
- func Int32D5(list [][][][][]int32) [][][][][]int32
- func Int32D5DeepCopy(list [][][][][]int32) [][][][][]int32
- func Int64(list []int64) []int64
- func Int64D2(list [][]int64) [][]int64
- func Int64D2DeepCopy(list [][]int64) [][]int64
- func Int64D3(list [][][]int64) [][][]int64
- func Int64D3DeepCopy(list [][][]int64) [][][]int64
- func Int64D4(list [][][][]int64) [][][][]int64
- func Int64D4DeepCopy(list [][][][]int64) [][][][]int64
- func Int64D5(list [][][][][]int64) [][][][][]int64
- func Int64D5DeepCopy(list [][][][][]int64) [][][][][]int64
- func Int8(list []int8) []int8
- func Int8D2(list [][]int8) [][]int8
- func Int8D2DeepCopy(list [][]int8) [][]int8
- func Int8D3(list [][][]int8) [][][]int8
- func Int8D3DeepCopy(list [][][]int8) [][][]int8
- func Int8D4(list [][][][]int8) [][][][]int8
- func Int8D4DeepCopy(list [][][][]int8) [][][][]int8
- func Int8D5(list [][][][][]int8) [][][][][]int8
- func Int8D5DeepCopy(list [][][][][]int8) [][][][][]int8
- func IntD2(list [][]int) [][]int
- func IntD2DeepCopy(list [][]int) [][]int
- func IntD3(list [][][]int) [][][]int
- func IntD3DeepCopy(list [][][]int) [][][]int
- func IntD4(list [][][][]int) [][][][]int
- func IntD4DeepCopy(list [][][][]int) [][][][]int
- func IntD5(list [][][][][]int) [][][][][]int
- func IntD5DeepCopy(list [][][][][]int) [][][][][]int
- func Interface(list []interface{}) []interface{}
- func InterfaceD2(list [][]interface{}) [][]interface{}
- func InterfaceD2DeepCopy(list [][]interface{}) [][]interface{}
- func InterfaceD3(list [][][]interface{}) [][][]interface{}
- func InterfaceD3DeepCopy(list [][][]interface{}) [][][]interface{}
- func InterfaceD4(list [][][][]interface{}) [][][][]interface{}
- func InterfaceD4DeepCopy(list [][][][]interface{}) [][][][]interface{}
- func InterfaceD5(list [][][][][]interface{}) [][][][][]interface{}
- func InterfaceD5DeepCopy(list [][][][][]interface{}) [][][][][]interface{}
- func Pointer(list []unsafe.Pointer) []unsafe.Pointer
- func PointerD2(list [][]unsafe.Pointer) [][]unsafe.Pointer
- func PointerD2DeepCopy(list [][]unsafe.Pointer) [][]unsafe.Pointer
- func PointerD3(list [][][]unsafe.Pointer) [][][]unsafe.Pointer
- func PointerD3DeepCopy(list [][][]unsafe.Pointer) [][][]unsafe.Pointer
- func PointerD4(list [][][][]unsafe.Pointer) [][][][]unsafe.Pointer
- func PointerD4DeepCopy(list [][][][]unsafe.Pointer) [][][][]unsafe.Pointer
- func PointerD5(list [][][][][]unsafe.Pointer) [][][][][]unsafe.Pointer
- func PointerD5DeepCopy(list [][][][][]unsafe.Pointer) [][][][][]unsafe.Pointer
- func Rune(list []rune) []rune
- func RuneD2(list [][]rune) [][]rune
- func RuneD2DeepCopy(list [][]rune) [][]rune
- func RuneD3(list [][][]rune) [][][]rune
- func RuneD3DeepCopy(list [][][]rune) [][][]rune
- func RuneD4(list [][][][]rune) [][][][]rune
- func RuneD4DeepCopy(list [][][][]rune) [][][][]rune
- func RuneD5(list [][][][][]rune) [][][][][]rune
- func RuneD5DeepCopy(list [][][][][]rune) [][][][][]rune
- func String(list []string) []string
- func StringD2(list [][]string) [][]string
- func StringD2DeepCopy(list [][]string) [][]string
- func StringD3(list [][][]string) [][][]string
- func StringD3DeepCopy(list [][][]string) [][][]string
- func StringD4(list [][][][]string) [][][][]string
- func StringD4DeepCopy(list [][][][]string) [][][][]string
- func StringD5(list [][][][][]string) [][][][][]string
- func StringD5DeepCopy(list [][][][][]string) [][][][][]string
- func UInt(list []uint) []uint
- func UInt16(list []uint16) []uint16
- func UInt16D2(list [][]uint16) [][]uint16
- func UInt16D2DeepCopy(list [][]uint16) [][]uint16
- func UInt16D3(list [][][]uint16) [][][]uint16
- func UInt16D3DeepCopy(list [][][]uint16) [][][]uint16
- func UInt16D4(list [][][][]uint16) [][][][]uint16
- func UInt16D4DeepCopy(list [][][][]uint16) [][][][]uint16
- func UInt16D5(list [][][][][]uint16) [][][][][]uint16
- func UInt16D5DeepCopy(list [][][][][]uint16) [][][][][]uint16
- func UInt32(list []uint32) []uint32
- func UInt32D2(list [][]uint32) [][]uint32
- func UInt32D2DeepCopy(list [][]uint32) [][]uint32
- func UInt32D3(list [][][]uint32) [][][]uint32
- func UInt32D3DeepCopy(list [][][]uint32) [][][]uint32
- func UInt32D4(list [][][][]uint32) [][][][]uint32
- func UInt32D4DeepCopy(list [][][][]uint32) [][][][]uint32
- func UInt32D5(list [][][][][]uint32) [][][][][]uint32
- func UInt32D5DeepCopy(list [][][][][]uint32) [][][][][]uint32
- func UInt64(list []uint64) []uint64
- func UInt64D2(list [][]uint64) [][]uint64
- func UInt64D2DeepCopy(list [][]uint64) [][]uint64
- func UInt64D3(list [][][]uint64) [][][]uint64
- func UInt64D3DeepCopy(list [][][]uint64) [][][]uint64
- func UInt64D4(list [][][][]uint64) [][][][]uint64
- func UInt64D4DeepCopy(list [][][][]uint64) [][][][]uint64
- func UInt64D5(list [][][][][]uint64) [][][][][]uint64
- func UInt64D5DeepCopy(list [][][][][]uint64) [][][][][]uint64
- func UInt8(list []uint8) []uint8
- func UInt8D2(list [][]uint8) [][]uint8
- func UInt8D2DeepCopy(list [][]uint8) [][]uint8
- func UInt8D3(list [][][]uint8) [][][]uint8
- func UInt8D3DeepCopy(list [][][]uint8) [][][]uint8
- func UInt8D4(list [][][][]uint8) [][][][]uint8
- func UInt8D4DeepCopy(list [][][][]uint8) [][][][]uint8
- func UInt8D5(list [][][][][]uint8) [][][][][]uint8
- func UInt8D5DeepCopy(list [][][][][]uint8) [][][][][]uint8
- func UIntD2(list [][]uint) [][]uint
- func UIntD2DeepCopy(list [][]uint) [][]uint
- func UIntD3(list [][][]uint) [][][]uint
- func UIntD3DeepCopy(list [][][]uint) [][][]uint
- func UIntD4(list [][][][]uint) [][][][]uint
- func UIntD4DeepCopy(list [][][][]uint) [][][][]uint
- func UIntD5(list [][][][][]uint) [][][][][]uint
- func UIntD5DeepCopy(list [][][][][]uint) [][][][][]uint
- func UIntPtr(list []uintptr) []uintptr
- func UIntPtrD2(list [][]uintptr) [][]uintptr
- func UIntPtrD2DeepCopy(list [][]uintptr) [][]uintptr
- func UIntPtrD3(list [][][]uintptr) [][][]uintptr
- func UIntPtrD3DeepCopy(list [][][]uintptr) [][][]uintptr
- func UIntPtrD4(list [][][][]uintptr) [][][][]uintptr
- func UIntPtrD4DeepCopy(list [][][][]uintptr) [][][][]uintptr
- func UIntPtrD5(list [][][][][]uintptr) [][][][][]uintptr
- func UIntPtrD5DeepCopy(list [][][][][]uintptr) [][][][][]uintptr
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BoolD2DeepCopy ¶
BoolD2DeepCopy makes a deep copy of the given list. The copy is returned.
func BoolD3DeepCopy ¶
BoolD3DeepCopy makes a deep copy of the given list. The copy is returned.
func BoolD4DeepCopy ¶
BoolD4DeepCopy makes a deep copy of the given list. The copy is returned.
func BoolD5DeepCopy ¶
BoolD5DeepCopy makes a deep copy of the given list. The copy is returned.
func ByteD2DeepCopy ¶
ByteD2DeepCopy makes a deep copy of the given list. The copy is returned.
func ByteD3DeepCopy ¶
ByteD3DeepCopy makes a deep copy of the given list. The copy is returned.
func ByteD4DeepCopy ¶
ByteD4DeepCopy makes a deep copy of the given list. The copy is returned.
func ByteD5DeepCopy ¶
ByteD5DeepCopy makes a deep copy of the given list. The copy is returned.
func Complex128 ¶
func Complex128(list []complex128) []complex128
Complex128 makes a copy of the given list. The copy is returned.
func Complex128D2 ¶
func Complex128D2(list [][]complex128) [][]complex128
Complex128D2 makes a shallow copy of the given list. The copy is returned.
func Complex128D2DeepCopy ¶
func Complex128D2DeepCopy(list [][]complex128) [][]complex128
Complex128D2DeepCopy makes a deep copy of the given list. The copy is returned.
func Complex128D3 ¶
func Complex128D3(list [][][]complex128) [][][]complex128
Complex128D3 makes a shallow copy of the given list. The copy is returned.
func Complex128D3DeepCopy ¶
func Complex128D3DeepCopy(list [][][]complex128) [][][]complex128
Complex128D3DeepCopy makes a deep copy of the given list. The copy is returned.
func Complex128D4 ¶
func Complex128D4(list [][][][]complex128) [][][][]complex128
Complex128D4 makes a shallow copy of the given list. The copy is returned.
func Complex128D4DeepCopy ¶
func Complex128D4DeepCopy(list [][][][]complex128) [][][][]complex128
Complex128D4DeepCopy makes a deep copy of the given list. The copy is returned.
func Complex128D5 ¶
func Complex128D5(list [][][][][]complex128) [][][][][]complex128
Complex128D5 makes a shallow copy of the given list. The copy is returned.
func Complex128D5DeepCopy ¶
func Complex128D5DeepCopy(list [][][][][]complex128) [][][][][]complex128
Complex128D5DeepCopy makes a deep copy of the given list. The copy is returned.
func Complex64D2 ¶
Complex64D2 makes a shallow copy of the given list. The copy is returned.
func Complex64D2DeepCopy ¶
Complex64D2DeepCopy makes a deep copy of the given list. The copy is returned.
func Complex64D3 ¶
Complex64D3 makes a shallow copy of the given list. The copy is returned.
func Complex64D3DeepCopy ¶
Complex64D3DeepCopy makes a deep copy of the given list. The copy is returned.
func Complex64D4 ¶
Complex64D4 makes a shallow copy of the given list. The copy is returned.
func Complex64D4DeepCopy ¶
Complex64D4DeepCopy makes a deep copy of the given list. The copy is returned.
func Complex64D5 ¶
Complex64D5 makes a shallow copy of the given list. The copy is returned.
func Complex64D5DeepCopy ¶
Complex64D5DeepCopy makes a deep copy of the given list. The copy is returned.
func ErrorD2DeepCopy ¶
ErrorD2DeepCopy makes a deep copy of the given list. The copy is returned.
func ErrorD3DeepCopy ¶
ErrorD3DeepCopy makes a deep copy of the given list. The copy is returned.
func ErrorD4DeepCopy ¶
ErrorD4DeepCopy makes a deep copy of the given list. The copy is returned.
func ErrorD5DeepCopy ¶
ErrorD5DeepCopy makes a deep copy of the given list. The copy is returned.
func Float32D2DeepCopy ¶
Float32D2DeepCopy makes a deep copy of the given list. The copy is returned.
func Float32D3DeepCopy ¶
Float32D3DeepCopy makes a deep copy of the given list. The copy is returned.
func Float32D4DeepCopy ¶
Float32D4DeepCopy makes a deep copy of the given list. The copy is returned.
func Float32D5DeepCopy ¶
Float32D5DeepCopy makes a deep copy of the given list. The copy is returned.
func Float64D2DeepCopy ¶
Float64D2DeepCopy makes a deep copy of the given list. The copy is returned.
func Float64D3DeepCopy ¶
Float64D3DeepCopy makes a deep copy of the given list. The copy is returned.
func Float64D4DeepCopy ¶
Float64D4DeepCopy makes a deep copy of the given list. The copy is returned.
func Float64D5DeepCopy ¶
Float64D5DeepCopy makes a deep copy of the given list. The copy is returned.
func Int16D2DeepCopy ¶
Int16D2DeepCopy makes a deep copy of the given list. The copy is returned.
func Int16D3DeepCopy ¶
Int16D3DeepCopy makes a deep copy of the given list. The copy is returned.
func Int16D4DeepCopy ¶
Int16D4DeepCopy makes a deep copy of the given list. The copy is returned.
func Int16D5DeepCopy ¶
Int16D5DeepCopy makes a deep copy of the given list. The copy is returned.
func Int32D2DeepCopy ¶
Int32D2DeepCopy makes a deep copy of the given list. The copy is returned.
func Int32D3DeepCopy ¶
Int32D3DeepCopy makes a deep copy of the given list. The copy is returned.
func Int32D4DeepCopy ¶
Int32D4DeepCopy makes a deep copy of the given list. The copy is returned.
func Int32D5DeepCopy ¶
Int32D5DeepCopy makes a deep copy of the given list. The copy is returned.
func Int64D2DeepCopy ¶
Int64D2DeepCopy makes a deep copy of the given list. The copy is returned.
func Int64D3DeepCopy ¶
Int64D3DeepCopy makes a deep copy of the given list. The copy is returned.
func Int64D4DeepCopy ¶
Int64D4DeepCopy makes a deep copy of the given list. The copy is returned.
func Int64D5DeepCopy ¶
Int64D5DeepCopy makes a deep copy of the given list. The copy is returned.
func Int8D2DeepCopy ¶
Int8D2DeepCopy makes a deep copy of the given list. The copy is returned.
func Int8D3DeepCopy ¶
Int8D3DeepCopy makes a deep copy of the given list. The copy is returned.
func Int8D4DeepCopy ¶
Int8D4DeepCopy makes a deep copy of the given list. The copy is returned.
func Int8D5DeepCopy ¶
Int8D5DeepCopy makes a deep copy of the given list. The copy is returned.
func IntD2DeepCopy ¶
IntD2DeepCopy makes a deep copy of the given list. The copy is returned.
func IntD3DeepCopy ¶
IntD3DeepCopy makes a deep copy of the given list. The copy is returned.
func IntD4DeepCopy ¶
IntD4DeepCopy makes a deep copy of the given list. The copy is returned.
func IntD5DeepCopy ¶
IntD5DeepCopy makes a deep copy of the given list. The copy is returned.
func Interface ¶
func Interface(list []interface{}) []interface{}
Interface makes a copy of the given list. The copy is returned. The object referenced by interface is not cloned.
func InterfaceD2 ¶
func InterfaceD2(list [][]interface{}) [][]interface{}
InterfaceD2 makes a shallow copy of the given list. The copy is returned.
func InterfaceD2DeepCopy ¶
func InterfaceD2DeepCopy(list [][]interface{}) [][]interface{}
InterfaceD2DeepCopy makes a deep copy of the given list. The copy is returned. The object referenced by interface is not cloned.
func InterfaceD3 ¶
func InterfaceD3(list [][][]interface{}) [][][]interface{}
InterfaceD3 makes a shallow copy of the given list. The copy is returned.
func InterfaceD3DeepCopy ¶
func InterfaceD3DeepCopy(list [][][]interface{}) [][][]interface{}
InterfaceD3DeepCopy makes a deep copy of the given list. The copy is returned. The object referenced by interface is not cloned.
func InterfaceD4 ¶
func InterfaceD4(list [][][][]interface{}) [][][][]interface{}
InterfaceD4 makes a shallow copy of the given list. The copy is returned.
func InterfaceD4DeepCopy ¶
func InterfaceD4DeepCopy(list [][][][]interface{}) [][][][]interface{}
InterfaceD4DeepCopy makes a deep copy of the given list. The copy is returned. The object referenced by interface is not cloned.
func InterfaceD5 ¶
func InterfaceD5(list [][][][][]interface{}) [][][][][]interface{}
InterfaceD5 makes a shallow copy of the given list. The copy is returned.
func InterfaceD5DeepCopy ¶
func InterfaceD5DeepCopy(list [][][][][]interface{}) [][][][][]interface{}
InterfaceD5DeepCopy makes a deep copy of the given list. The copy is returned. The object referenced by interface is not cloned.
func PointerD2DeepCopy ¶
PointerD2DeepCopy makes a deep copy of the given list. The copy is returned. The data the unsafe pointer is pointing to is not cloned.
func PointerD3DeepCopy ¶
PointerD3DeepCopy makes a deep copy of the given list. The copy is returned. The data the unsafe pointer is pointing to is not cloned.
func PointerD4DeepCopy ¶
PointerD4DeepCopy makes a deep copy of the given list. The copy is returned. The data the unsafe pointer is pointing to is not cloned.
func PointerD5DeepCopy ¶
PointerD5DeepCopy makes a deep copy of the given list. The copy is returned. The data the unsafe pointer is pointing to is not cloned.
func RuneD2DeepCopy ¶
RuneD2DeepCopy makes a deep copy of the given list. The copy is returned.
func RuneD3DeepCopy ¶
RuneD3DeepCopy makes a deep copy of the given list. The copy is returned.
func RuneD4DeepCopy ¶
RuneD4DeepCopy makes a deep copy of the given list. The copy is returned.
func RuneD5DeepCopy ¶
RuneD5DeepCopy makes a deep copy of the given list. The copy is returned.
func StringD2DeepCopy ¶
StringD2DeepCopy makes a deep copy of the given list. The copy is returned.
func StringD3DeepCopy ¶
StringD3DeepCopy makes a deep copy of the given list. The copy is returned.
func StringD4DeepCopy ¶
StringD4DeepCopy makes a deep copy of the given list. The copy is returned.
func StringD5DeepCopy ¶
StringD5DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt16D2DeepCopy ¶
UInt16D2DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt16D3DeepCopy ¶
UInt16D3DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt16D4DeepCopy ¶
UInt16D4DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt16D5DeepCopy ¶
UInt16D5DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt32D2DeepCopy ¶
UInt32D2DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt32D3DeepCopy ¶
UInt32D3DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt32D4DeepCopy ¶
UInt32D4DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt32D5DeepCopy ¶
UInt32D5DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt64D2DeepCopy ¶
UInt64D2DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt64D3DeepCopy ¶
UInt64D3DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt64D4DeepCopy ¶
UInt64D4DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt64D5DeepCopy ¶
UInt64D5DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt8D2DeepCopy ¶
UInt8D2DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt8D3DeepCopy ¶
UInt8D3DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt8D4DeepCopy ¶
UInt8D4DeepCopy makes a deep copy of the given list. The copy is returned.
func UInt8D5DeepCopy ¶
UInt8D5DeepCopy makes a deep copy of the given list. The copy is returned.
func UIntD2DeepCopy ¶
UIntD2DeepCopy makes a deep copy of the given list. The copy is returned.
func UIntD3DeepCopy ¶
UIntD3DeepCopy makes a deep copy of the given list. The copy is returned.
func UIntD4DeepCopy ¶
UIntD4DeepCopy makes a deep copy of the given list. The copy is returned.
func UIntD5DeepCopy ¶
UIntD5DeepCopy makes a deep copy of the given list. The copy is returned.
func UIntPtrD2DeepCopy ¶
UIntPtrD2DeepCopy makes a deep copy of the given list. The copy is returned.
func UIntPtrD3DeepCopy ¶
UIntPtrD3DeepCopy makes a deep copy of the given list. The copy is returned.
func UIntPtrD4DeepCopy ¶
UIntPtrD4DeepCopy makes a deep copy of the given list. The copy is returned.
func UIntPtrD5DeepCopy ¶
UIntPtrD5DeepCopy makes a deep copy of the given list. The copy is returned.
Types ¶
This section is empty.